@@ -1,5 +1,5 @@
 package Test::Class::Moose;
-$Test::Class::Moose::VERSION = '0.59';
+$Test::Class::Moose::VERSION = '0.60';
 # ABSTRACT: Serious testing for serious Perl
 
 use 5.10.0;
@@ -237,15 +237,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.59
+version 0.60
 
 =head1 SYNOPSIS
 
@@ -967,9 +965,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * GitHub Issues (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Test-Class-Moose>
+L<https://github.com/test-class-moose/test-class-moose/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -979,9 +977,9 @@ L<http://annocpan.org/dist/Test-Class-Moose>
 
 L<http://cpanratings.perl.org/d/Test-Class-Moose>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/Test-Class-Moose/>
+L<https://metacpan.org/release/Test-Class-Moose/>
 
 =back
 
@@ -1010,42 +1008,90 @@ L<Test::Class> + L<Test::Most>.
 
 =back
 
-=head1 CONTRIBUTORS
-
-=over 4
-
-=item * Dave Rolsky <autarch@urth.org>
-
-=item * Doug Bell <doug.bell@baml.com>
-
-=item * Gregory Oschwald <goschwald@maxmind.com>
-
-=item * Jonathan C. Otsuka <djgoku@gmail.com>
-
-=item * Neil Bowers <neil@bowers.com>
-
-=item * Olaf Alders <olaf@wundersolutions.com>
-
-=item * Ovid <curtis\_ovid\_poe@yahoo.com>
-
-=item * Paul Boyd <pboyd@dev3l.net>
-
-=item * Petrea Corneliu Stefan <stefan@garage-coding.com>
-
-=item * Stuckdownawell <stuckdownawell@gmail.com>
-
-=item * Tom Beresford <tom.beresford@bskyb.com>
-
-=item * Tom Heady <tom@punch.net>
-
-=item * Udo Oji <Velti@signor.com>
-
-=back
-
 =head1 AUTHOR
 
 Curtis "Ovid" Poe <ovid@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Dave Rolsky Petrea Corneliu Stefan Steven Humphrey Stuckdownawell Tim Vroom Tom Beresford Heady Udo Oji mephinet Doug Bell Gregory Oschwald Jeremy Krieg Jonathan C. Otsuka Stowe Karen Etheridge Neil Bowers Olaf Alders Paul Boyd
+
+=over 4
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Petrea Corneliu Stefan <stefan@garage-coding.com>
+
+=item *
+
+Steven Humphrey <catchgithub@33k.co.uk>
+
+=item *
+
+Stuckdownawell <stuckdownawell@gmail.com>
+
+=item *
+
+Tim Vroom <vroom@blockstackers.com>
+
+=item *
+
+Tom Beresford <tom.beresford@bskyb.com>
+
+=item *
+
+Tom Heady <tom@punch.net>
+
+=item *
+
+Udo Oji <Velti@signor.com>
+
+=item *
+
+mephinet <mephinet@gmx.net>
+
+=item *
+
+Doug Bell <madcityzen@gmail.com>
+
+=item *
+
+Gregory Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Jeremy Krieg <Jeremy.Krieg@YourAmigo.com>
+
+=item *
+
+Jonathan C. Otsuka <djgoku@gmail.com>
+
+=item *
+
+Jonathan Stowe <jns@gellyfish.co.uk>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Neil Bowers <neil@bowers.com>
+
+=item *
+
+Olaf Alders <olaf@wundersolutions.com>
+
+=item *
+
+Paul Boyd <pboyd@dev3l.net>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Curtis "Ovid" Poe.
